@@ -33,7 +33,7 @@ void ezio::wait(int interval_second)
 	}
 }
 
-void ezio::add_torrent(std::string torrent_body, std::string save_path, bool seeding_mode = false, int max_uploads = 3, int max_connections = 5)
+void ezio::add_torrent(std::string torrent_body, std::string save_path, bool seeding_mode = false, int max_uploads = 3, int max_connections = 5, bool sequential_download = false)
 {
 	lt::span<const char> torrent_byte(torrent_body);
 
@@ -59,6 +59,10 @@ void ezio::add_torrent(std::string torrent_body, std::string save_path, bool see
 		atp.flags |= libtorrent::torrent_flags::seed_mode;
 	}
 
+	if (sequential_download) {
+		atp.flags |= libtorrent::torrent_flags::sequential_download;
+	}
+
 	if (ec) {
 		throw std::invalid_argument("failed to save path");
 	}
@@ -78,6 +82,8 @@ std::map<std::string, torrent_status> ezio::get_torrent_status(std::vector<std::
 		// do some filter for below
 	}
 
+	auto now = std::chrono::high_resolution_clock::now();
+
 	std::vector<lt::torrent_handle> torrents = session_.get_torrents();
 	for (lt::torrent_handle const &h : torrents) {
 		std::stringstream ss;
@@ -108,6 +114,16 @@ std::map<std::string, torrent_status> ezio::get_torrent_status(std::vector<std::
 		status.is_paused = (t_stat.flags & libtorrent::torrent_flags::paused) != 0;
 		status.save_path = t_stat.save_path;
 
+		status.last_upload = -1;
+		if (t_stat.last_upload.time_since_epoch().count() != 0) {
+			status.last_upload = std::chrono::duration_cast<std::chrono::seconds>(now - t_stat.last_upload).count();
+		}
+
+		status.last_download = -1;
+		if (t_stat.last_download.time_since_epoch().count() != 0) {
+			status.last_download = std::chrono::duration_cast<std::chrono::seconds>(now - t_stat.last_download).count();
+		}
+
 		result.emplace(hash, status);
 	}
 
